@@ -1,11 +1,13 @@
 package WebService::Mattermost;
 
+# ABSTRACT: Perl client library for Mattermost's REST API and websocket gateway
+
 use Moo;
 use Types::Standard qw(Bool Int Object Str);
 
 use WebService::Mattermost::V4::API;
 
-our $VERSION = 0.22;
+our $VERSION = 0.23;
 
 ################################################################################
 
@@ -89,11 +91,20 @@ sub _build_api {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost - Perl client library for Mattermost.
+WebService::Mattermost - Perl client library for Mattermost's REST API and websocket gateway
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -188,5 +199,14 @@ Accessible from this class via the C<api> attribute.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
