@@ -1,5 +1,7 @@
 package WebService::Mattermost::Helper::Alias;
 
+# ABSTRACT: Alias helper for shortening package names.
+
 use strict;
 use warnings;
 
@@ -39,11 +41,20 @@ sub view {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::Helper::Alias
+WebService::Mattermost::Helper::Alias - Alias helper for shortening package names.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -66,5 +77,14 @@ Format the name of an endpoint for the version 4 API.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
