@@ -1,5 +1,7 @@
 package WebService::Mattermost::Role::Logger;
 
+# ABSTRACT: Internal logger role.
+
 use Moo::Role;
 use Types::Standard 'InstanceOf';
 
@@ -19,11 +21,20 @@ sub _build_logger {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::Role::Logger
+WebService::Mattermost::Role::Logger - Internal logger role.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -63,5 +74,14 @@ A C<Mojo::Log> object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
