@@ -1,5 +1,7 @@
 package WebService::Mattermost::Role::Returns;
 
+# ABSTRACT: Standard returns for user-facing subroutines.
+
 use Moo::Role;
 
 ################################################################################
@@ -16,11 +18,20 @@ sub error_return {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::Role::Returns
+WebService::Mattermost::Role::Returns - Standard returns for user-facing subroutines.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -45,5 +56,14 @@ Return an unsuccessful response with an error message.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
