@@ -1,5 +1,7 @@
 package WebService::Mattermost::Util::Logger;
 
+# ABSTRACT: Internal logger.
+
 use Moo;
 use Mojo::Util 'monkey_patch';
 use Mojo::Log;
@@ -34,11 +36,20 @@ sub _build_logger {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::Util::Logger
+WebService::Mattermost::Util::Logger - Internal logger.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -76,5 +87,14 @@ A C<Mojo::Log> object with additional methods:
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
