@@ -1,5 +1,7 @@
 package WebService::Mattermost::Util::UserAgent;
 
+# ABSTRACT: Internal user agent.
+
 use Moo;
 use Mojo::UserAgent;
 use Types::Standard qw(Bool InstanceOf Int);
@@ -27,15 +29,24 @@ sub _build_ua {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::Util::UserAgent
+WebService::Mattermost::Util::UserAgent - Internal user agent.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
-Wraps C<Mojo::Log> with standard parameters for the project.
+Adds standard parameters to C<Mojo::UserAgent>.
 
 =head2 ATTRIBUTES
 
@@ -57,5 +68,14 @@ The default maximum number of redirects (5).
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
