@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Analytics::Old;
 
+# ABSTRACT: An "old" Analytics item.
+
 use Moo;
 use Types::Standard qw(Int Maybe);
 
@@ -12,15 +14,24 @@ with    qw(
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Analytics::Old
+WebService::Mattermost::V4::API::Object::Analytics::Old - An "old" Analytics item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
-Details an old Mattermost analytics node.
+Details an old Mattermost analytics item.
 
 =head1 SEE ALSO
 
@@ -34,5 +45,14 @@ Details an old Mattermost analytics node.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
