@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Application;
 
+# ABSTRACT: An application item.
+
 use Moo;
 use Types::Standard qw(ArrayRef Bool Maybe Str);
 
@@ -31,11 +33,20 @@ sub _build_is_trusted    { shift->raw_data->{is_trusted}    }
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Application
+WebService::Mattermost::V4::API::Object::Application - An application item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -65,5 +76,14 @@ Details a Mattermost Application object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
