@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Audit;
 
+# ABSTRACT: An audit item.
+
 use Moo;
 use Types::Standard qw(Maybe Str);
 
@@ -27,11 +29,20 @@ sub _build_session_id { shift->raw_data->{session_id} }
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Audit
+WebService::Mattermost::V4::API::Object::Audit - An audit item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -51,5 +62,14 @@ Details a generic response from Mattermost.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
