@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Binary;
 
+# ABSTRACT: A binary item.
+
 use Moo;
 use Types::Standard qw(Maybe Str);
 
@@ -16,11 +18,20 @@ sub _build_content { shift->raw_content }
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Binary
+WebService::Mattermost::V4::API::Object::Binary - A binary item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -38,5 +49,14 @@ Raw binary content.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
