@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Channel::Member;
 
+# ABSTRACT: A channel member item.
+
 use Moo;
 use Types::Standard qw(HashRef InstanceOf Int Maybe Str);
 
@@ -43,11 +45,20 @@ sub _build_last_viewed {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Channel::Member
+WebService::Mattermost::V4::API::Object::Channel::Member - A channel member item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -95,5 +106,14 @@ DateTime.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
