@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::ChannelStats;
 
+# ABSTRACT: A channel stats item.
+
 use Moo;
 use Types::Standard qw(Int Maybe);
 
@@ -19,11 +21,20 @@ sub _build_member_count { shift->raw_data->{member_count} }
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::ChannelStats
+WebService::Mattermost::V4::API::Object::ChannelStats - A channel stats item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -49,5 +60,14 @@ Details a Mattermost ChannelStats object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
