@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Compliance::Report;
 
+# ABSTRACT: A compliance report item.
+
 use Moo;
 use Types::Standard qw(Str InstanceOf Int Maybe);
 
@@ -80,11 +82,20 @@ sub _build_emails {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Compliance::Report
+WebService::Mattermost::V4::API::Object::Compliance::Report - A compliance report item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -95,7 +106,7 @@ ID parameters are not required:
 
     my $response = $mattermost->api->compliance_report->get('ID-HERE')->item->download();
 
-Is the same as: 
+Is the same as:
 
     my $response = $mattermost->api->compliance_report->download('ID-HERE');
 
@@ -141,5 +152,14 @@ Is the same as:
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
