@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Config;
 
+# ABSTRACT: A config item.
+
 use Moo;
 use Types::Standard qw(HashRef Maybe);
 
@@ -60,11 +62,20 @@ sub _build_webrtc_settings        { shift->raw_data->{WebrtcSettings}        }
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Config
+WebService::Mattermost::V4::API::Object::Config - A config item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -122,5 +133,14 @@ Describes a Mattermost configuration response.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
