@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::DataRetentionPolicy;
 
+# ABSTRACT: A data retention item.
+
 use Moo;
 use Types::Standard qw(Bool Maybe InstanceOf Int);
 
@@ -8,7 +10,7 @@ extends 'WebService::Mattermost::V4::API::Object';
 ################################################################################
 
 has [ qw(
-    message_deletion_enabled 
+    message_deletion_enabled
     file_deletion_enabled
 ) ] => (is => 'ro', isa => Maybe[Bool], lazy => 1, builder => 1);
 
@@ -46,11 +48,20 @@ sub _build_messages_kept_until {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::DataRetentionPolicy
+WebService::Mattermost::V4::API::Object::DataRetentionPolicy - A data retention item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -84,5 +95,14 @@ DateTime.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
