@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Error;
 
+# ABSTRACT: An error item.
+
 use Moo;
 use Types::Standard qw(Str Maybe);
 
@@ -44,11 +46,20 @@ sub _build_status_code {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Error
+WebService::Mattermost::V4::API::Object::Error - An error item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -82,5 +93,14 @@ Official documentation for API errors.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
