@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Icon;
 
+# ABSTRACT: An icon item.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Object';
@@ -13,11 +15,20 @@ with    qw(
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Icon
+WebService::Mattermost::V4::API::Object::Icon - An icon item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -49,5 +60,14 @@ Details a Mattermost Icon object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
