@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Job;
 
+# ABSTRACT: A job item.
+
 use Moo;
 use Types::Standard qw(HashRef Int Maybe Object Str);
 
@@ -72,11 +74,20 @@ sub _build_started_at {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Job
+WebService::Mattermost::V4::API::Object::Job - A job item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -137,5 +148,14 @@ DateTime.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
