@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Log;
 
+# ABSTRACT: A log item.
+
 use Moo;
 use Types::Standard qw(Maybe InstanceOf Int Str);
 
@@ -26,11 +28,20 @@ sub _build_timestamp {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Log
+WebService::Mattermost::V4::API::Object::Log - A log item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -56,5 +67,14 @@ DateTime.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
