@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::NewLogEntry;
 
+# ABSTRACT: A new log entry item.
+
 use Moo;
 use Types::Standard qw(Maybe InstanceOf Int Str);
 
@@ -17,11 +19,20 @@ sub _build_level  { shift->raw_data->{level}  }
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::NewLogEntry
+WebService::Mattermost::V4::API::Object::NewLogEntry - A new log entry item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -37,5 +48,14 @@ Details a Mattermost NewLogEntry object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
