@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Plugin;
 
+# ABSTRACT: A plugin item.
+
 use Moo;
 use Types::Standard qw(Bool HashRef Maybe Str);
 
@@ -44,11 +46,20 @@ sub BUILD {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Plugin
+WebService::Mattermost::V4::API::Object::Plugin - A plugin item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -111,5 +122,14 @@ Is the same as:
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
