@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Plugins;
 
+# ABSTRACT: Many plugin items.
+
 use Moo;
 use Types::Standard qw(ArrayRef Maybe);
 
@@ -50,3 +52,58 @@ sub _build_inactive {
 
 1;
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+WebService::Mattermost::V4::API::Object::Plugins - Many plugin items.
+
+=head1 VERSION
+
+version 0.23
+
+=head1 DESCRIPTION
+
+Contains active and inactive plugins.
+
+=head2 ATTRIBUTES
+
+=over 4
+
+=item * C<active>
+
+A list of enabled plugins.
+
+=item * C<inactive>
+
+A list of disabled plugins.
+
+=back
+
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<WebService::Mattermost::V4::API::Object::Plugin>
+
+The "plugins" referred to in C<active> and C<inactive>.
+
+=back
+
+=head1 AUTHOR
+
+Mike Jones <mike@netsplit.org.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
