@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Reaction;
 
+# ABSTRACT: A reaction item.
+
 use Moo;
 use Types::Standard qw(InstanceOf Maybe Str);
 
@@ -31,11 +33,20 @@ sub _build_emoji {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Reaction
+WebService::Mattermost::V4::API::Object::Reaction - A reaction item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -69,5 +80,14 @@ Related L<WebService::Mattermost::V4::API::Object::Emoji> object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
