@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Results;
 
+# ABSTRACT: A result object.
+
 use Moo;
 use Types::Standard qw(Maybe Str);
 
@@ -16,17 +18,46 @@ sub _build_results { shift->raw_data->{results} }
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Results
+WebService::Mattermost::V4::API::Object::Results - A result object.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
-Details a Mattermost Results object.
+Details a Mattermost Results object. Returned only by L<WebService::Mattermost::V4::API::Resource::Team>'s
+C<import_from_existing()> method.
+
+=head2 ATTRIBUTES
+
+=over 4
+
+=item * C<results>
+
+Stringified "results".
+
+=back
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
