@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Role::BelongingToChannel;
 
+# ABSTRACT: Mark an object as belonging to a channel.
+
 use Moo::Role;
 use Types::Standard qw(InstanceOf Maybe Str);
 
@@ -28,11 +30,20 @@ sub _build_channel {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Role::BelongingToChannel
+WebService::Mattermost::V4::API::Object::Role::BelongingToChannel - Mark an object as belonging to a channel.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -54,5 +65,14 @@ Linked L<WebService::Mattermost::V4::API::Object::Channel> object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
