@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Role::BelongingToPost;
 
+# ABSTRACT: Mark an object as belonging to a post.
+
 use Moo::Role;
 use Types::Standard qw(Maybe InstanceOf Str);
 
@@ -22,11 +24,20 @@ sub _build_post {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Role::BelongingToPost
+WebService::Mattermost::V4::API::Object::Role::BelongingToPost - Mark an object as belonging to a post.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -48,5 +59,14 @@ Linked L<WebService::Mattermost::V4::API::Object::Post> object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
