@@ -1,12 +1,12 @@
 package WebService::Mattermost::V4::API::Object::Role::BelongingToTeam;
 
+# ABSTRACT: Mark an object as belonging to a team.
+
 use Moo::Role;
 use Types::Standard qw(InstanceOf Maybe Str);
 
 use WebService::Mattermost::Helper::Alias 'view';
 
-#requires 'raw_data';
-
 ################################################################################
 
 has team_id => (is => 'ro', isa => Maybe[Str],                     lazy => 1, builder => 1);
@@ -30,11 +30,20 @@ sub _build_team {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Role::BelongingToTeam
+WebService::Mattermost::V4::API::Object::Role::BelongingToTeam - Mark an object as belonging to a team.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -56,5 +65,14 @@ Linked L<WebService::Mattermost::V4::API::Object::Team> object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
