@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Role::BelongingToUser;
 
+# ABSTRACT: Mark an object as belonging to a user.
+
 use Moo::Role;
 use Types::Standard qw(InstanceOf Maybe Str);
 
@@ -15,7 +17,9 @@ has [ qw(user created_by) ] => (is => 'ro', isa => Maybe[InstanceOf[view 'User']
 sub _build_creator_id {
     my $self = shift;
 
-    return $self->raw_data->{creator_id} || $self->raw_data->{user_id};
+    return $self->raw_data->{creator_id}
+        || $self->raw_data->{owner_id}
+        || $self->raw_data->{user_id};
 }
 
 sub _build_created_by {
@@ -30,11 +34,20 @@ sub _build_user { shift->created_by }
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Role::BelongingToUser
+WebService::Mattermost::V4::API::Object::Role::BelongingToUser - Mark an object as belonging to a user.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -56,5 +69,14 @@ Linked L<WebService::Mattermost::V4::API::Object::User> object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
