@@ -1,10 +1,10 @@
 package WebService::Mattermost::V4::API::Object::Role::CreatedAt;
 
+# ABSTRACT: Adds a "created_at" attribute to an object.
+
 use Moo::Role;
 use Types::Standard qw(InstanceOf Int Maybe);
 
-#requires qw(_from_epoch raw_data);
-
 ################################################################################
 
 has create_at  => (is => 'ro', isa => Maybe[Int],                    lazy => 1, builder => 1);
@@ -27,11 +27,20 @@ sub _build_created_at {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Role::CreatedAt
+WebService::Mattermost::V4::API::Object::Role::CreatedAt - Adds a "created_at" attribute to an object.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -53,5 +62,14 @@ C<DateTime> object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
