@@ -1,10 +1,10 @@
 package WebService::Mattermost::V4::API::Object::Role::Description;
 
+# ABSTRACT: Adds a "description" field to an object.
+
 use Moo::Role;
 use Types::Standard qw(Maybe Str);
 
-#requires 'raw_data';
-
 ################################################################################
 
 has description => (is => 'ro', isa => Maybe[Str], lazy => 1, builder => 1);
@@ -20,11 +20,20 @@ sub _build_description {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Role::Description
+WebService::Mattermost::V4::API::Object::Role::Description - Adds a "description" field to an object.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -40,5 +49,14 @@ Attach a description to a v4::Object object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
