@@ -1,10 +1,10 @@
 package WebService::Mattermost::V4::API::Object::Role::ExpiresAt;
 
+# ABSTRACT: Adds an "expires_at" field to an object.
+
 use Moo::Role;
 use Types::Standard qw(InstanceOf Int Maybe);
 
-#requires qw(_from_epoch raw_data);
-
 ################################################################################
 
 has expires_at => (is => 'ro', isa => Maybe[Int],                    lazy => 1, builder => 1);
@@ -27,11 +27,20 @@ sub _build_expires {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Role::ExpiresAt
+WebService::Mattermost::V4::API::Object::Role::ExpiresAt - Adds an "expires_at" field to an object.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -51,7 +60,24 @@ C<DateTime> object.
 
 =back
 
+=head1 NAME
+
+WebService::Mattermost::V4::API::Object::Role::ExpiresAt
+
 =head1 AUTHOR
 
 Mike Jones L<email:mike@netsplit.org.uk>
 
+=head1 AUTHOR
+
+Mike Jones <mike@netsplit.org.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
