@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Role::Level;
 
+# ABSTRACT: Adds a "level" field to an object.
+
 use Moo::Role;
 use Types::Standard qw(Maybe Str);
 
@@ -18,11 +20,20 @@ sub _build_level {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Role::Level
+WebService::Mattermost::V4::API::Object::Role::Level - Adds a "level" field to an object.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -38,5 +49,14 @@ Attach an Level to a v4::Object object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
