@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Role::RequestID;
 
+# ABSTRACT: Adds a "request_id" field to an object.
+
 use Moo::Role;
 use Types::Standard qw(Maybe Str);
 
@@ -18,11 +20,20 @@ sub _build_request_id {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Role::RequestID
+WebService::Mattermost::V4::API::Object::Role::RequestID - Adds a "request_id" field to an object.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -40,5 +51,14 @@ UUID.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
