@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Role::Timestamps;
 
+# ABSTRACT: Adds common timestamp fields to an object.
+
 use Moo::Role;
 use Types::Standard qw(InstanceOf Int Maybe);
 
@@ -35,11 +37,20 @@ sub _build_deleted_at {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Role::Timestamps
+WebService::Mattermost::V4::API::Object::Role::Timestamps - Adds common timestamp fields to an object.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -69,5 +80,14 @@ C<DateTime> object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
