@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Role::UpdatedAt;
 
+# ABSTRACT: Adds an "updated_at" field to an object.
+
 use Moo::Role;
 use Types::Standard qw(InstanceOf Int Maybe);
 
@@ -25,11 +27,20 @@ sub _build_updated_at {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Role::UpdatedAt
+WebService::Mattermost::V4::API::Object::Role::UpdatedAt - Adds an "updated_at" field to an object.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -51,5 +62,14 @@ C<DateTime> object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
