@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Status;
 
+# ABSTRACT: A status object.
+
 use Moo;
 use Types::Standard qw(Str Int);
 
@@ -9,11 +11,20 @@ with    'WebService::Mattermost::V4::API::Object::Role::Status';
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Status
+WebService::Mattermost::V4::API::Object::Status - A status object.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -29,5 +40,14 @@ Details a Mattermost Status object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
