@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Team;
 
+# ABSTRACT: A team item.
+
 use Moo;
 use Types::Standard qw(Bool Str);
 
@@ -59,11 +61,20 @@ sub _build_open_invite    { shift->raw_data->{open_invite} ? 1 : 0 }
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Team
+WebService::Mattermost::V4::API::Object::Team - A team item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -164,5 +175,14 @@ Boolean.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
