@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::TeamStats;
 
+# ABSTRACT: Stats for a team.
+
 use Moo;
 use Types::Standard qw(Int Maybe);
 
@@ -23,11 +25,20 @@ sub _build_total_member_count  { shift->raw_data->{total_member_count}  }
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::TeamStats
+WebService::Mattermost::V4::API::Object::TeamStats - Stats for a team.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -55,5 +66,14 @@ Details a Mattermost TeamStats object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
