@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::Thread;
 
+# ABSTRACT: A message thread.
+
 use Moo;
 use Types::Standard qw(ArrayRef Maybe);
 
@@ -40,11 +42,20 @@ sub _build_posts {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::Thread
+WebService::Mattermost::V4::API::Object::Thread - A message thread.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -68,5 +79,14 @@ An arrayref of posts in the list, ordered by date created.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
