@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::User;
 
+# ABSTRACT: A user item.
+
 use Moo;
 use Types::Standard qw(ArrayRef Bool HashRef InstanceOf Int Maybe Str);
 
@@ -96,11 +98,20 @@ sub _build_picture_updated_at {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::User
+WebService::Mattermost::V4::API::Object::User - A user item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -165,5 +176,14 @@ Is the same as:
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
