@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::User::Preference;
 
+# ABSTRACT: A user preference item.
+
 use Moo;
 use Types::Standard qw(Maybe Str);
 
@@ -21,11 +23,20 @@ sub _build_value    { shift->raw_data->{value}    }
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::User::Preference
+WebService::Mattermost::V4::API::Object::User::Preference - A user preference item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -51,5 +62,14 @@ WebService::Mattermost::V4::API::Object::User::Preference
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
