@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::User::Session;
 
+# ABSTRACT: A user session item.
+
 use Moo;
 use Types::Standard qw(ArrayRef Bool Maybe Str);
 
@@ -31,11 +33,20 @@ sub _build_token        { shift->raw_data->{token}            }
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::User::Session
+WebService::Mattermost::V4::API::Object::User::Session - A user session item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -73,5 +84,14 @@ WebService::Mattermost::V4::API::Object::User::Session
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
