@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::User::Status;
 
+# ABSTRACT: A user status item.
+
 use Moo;
 use Types::Standard qw(Maybe Bool);
 
@@ -23,11 +25,20 @@ sub _build_manual {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::User::Status
+WebService::Mattermost::V4::API::Object::User::Status - A user status item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -55,3 +66,16 @@ Was the status set manually?
 
 =back
 
+=head1 AUTHOR
+
+Mike Jones <mike@netsplit.org.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
