@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Object::WebRTCToken;
 
+# ABSTRACT: A WebRTC token item.
+
 use Moo;
 use Types::Standard qw(Str Maybe);
 
@@ -28,11 +30,20 @@ sub _build_turn_username  { shift->raw_data->{turn_username} }
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Object::WebRTCToken
+WebService::Mattermost::V4::API::Object::WebRTCToken - A WebRTC token item.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -62,5 +73,14 @@ Details a Mattermost WebRTC token object.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
