@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Request;
 
+# ABSTRACT: A request to be sent to the Mattermost API.
+
 use Mojo::URL;
 use Mojo::Util 'url_escape';
 use Moo;
@@ -47,11 +49,20 @@ sub _build_url {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Request
+WebService::Mattermost::V4::API::Request - A request to be sent to the Mattermost API.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -91,5 +102,14 @@ IDs to replace into the URL with C<sprintf>.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
