@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource;
 
+# ABSTRACT: Base class for API resources.
+
 use List::MoreUtils 'all';
 use Moo;
 use Types::Standard qw(Bool HashRef Object Str);
@@ -235,11 +237,20 @@ sub _new_related_resource {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource - base class for API resources.
+WebService::Mattermost::V4::API::Resource - Base class for API resources.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -265,5 +276,14 @@ resource is 'brand'.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
