@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Audits;
 
+# ABSTRACT: Wrapped API methods for the audits API endpoints.
+
 use Moo;
 use Types::Standard 'Str';
 
@@ -21,11 +23,20 @@ sub get {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Audits
+WebService::Mattermost::V4::API::Resource::Audits - Wrapped API methods for the audits API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -60,5 +71,14 @@ L<Get audits|https://api.mattermost.com/#tag/system%2Fpaths%2F~1audits%2Fget>
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
