@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Brand;
 
+# ABSTRACT: Wrapped API methods for the brand API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -29,11 +31,20 @@ sub upload {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Brand
+WebService::Mattermost::V4::API::Resource::Brand - Wrapped API methods for the brand API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -82,5 +93,14 @@ Set a new brand image for your Mattermost server.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
