@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Channel;
 
+# ABSTRACT: Wrapped API methods for the channel API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -161,11 +163,20 @@ sub posts {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Channel
+WebService::Mattermost::V4::API::Resource::Channel - Wrapped API methods for the channel API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -280,5 +291,14 @@ L<Get posts for a channel|https://api.mattermost.com/#tag/posts%2Fpaths%2F~1chan
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
