@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Cluster;
 
+# ABSTRACT: Wrapped API methods for the cluster API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -15,11 +17,20 @@ sub status {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Cluster
+WebService::Mattermost::V4::API::Resource::Cluster - Wrapped API methods for the cluster API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -58,5 +69,14 @@ Official "cluster" API documentation.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
