@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Config;
 
+# ABSTRACT: Wrapped API methods for the config API endpoints.
+
 use Moo;
 use Types::Standard 'Str';
 
@@ -53,11 +55,20 @@ sub set_by_environment {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Config
+WebService::Mattermost::V4::API::Resource::Config - Wrapped API methods for the config API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -139,5 +150,14 @@ L<Get configuration made through environment variables|https://api.mattermost.co
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
