@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::DataRetention;
 
+# ABSTRACT: Wrapped API methods for the data retention API endpoints.
+
 use Moo;
 use Types::Standard 'Str';
 
@@ -20,11 +22,20 @@ sub policy {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::DataRetention
+WebService::Mattermost::V4::API::Resource::DataRetention - Wrapped API methods for the data retention API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -63,5 +74,14 @@ Official "DataRetention" API documentation.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
