@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Database;
 
+# ABSTRACT: Wrapped API methods for the database API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -18,11 +20,20 @@ sub recycle {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Database
+WebService::Mattermost::V4::API::Resource::Database - Wrapped API methods for the database API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -51,5 +62,14 @@ L<Recycle database connections|https://api.mattermost.com/#tag/system%2Fpaths%2F
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
