@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Email;
 
+# ABSTRACT: Wrapped API methods for the email API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -19,11 +21,20 @@ sub send_test {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Email
+WebService::Mattermost::V4::API::Resource::Email - Wrapped API methods for the email API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -83,5 +94,14 @@ Providing no parameters will use the ones set on your Mattermost server.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
