@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Emoji;
 
+# ABSTRACT: Wrapped API methods for the emoji API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -117,11 +119,20 @@ sub autocomplete {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Emoji
+WebService::Mattermost::V4::API::Resource::Emoji - Wrapped API methods for the emoji API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -200,5 +211,14 @@ Autocomplete an emoji name.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
