@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::File;
 
+# ABSTRACT: Wrapped API methods for the file API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -14,7 +16,7 @@ sub get {
         endpoint => '%s',
         ids      => [ $file_id ],
         view     => 'Binary',
-    }); 
+    });
 }
 
 sub get_thumbnail {
@@ -24,7 +26,7 @@ sub get_thumbnail {
     return $self->_get({
         endpoint => '%s/thumbnail',
         ids      => [ $file_id ],
-    }); 
+    });
 }
 
 sub get_preview {
@@ -34,7 +36,7 @@ sub get_preview {
     return $self->_get({
         endpoint => '%s/preview',
         ids      => [ $file_id ],
-    }); 
+    });
 }
 
 sub get_link {
@@ -44,7 +46,7 @@ sub get_link {
     return $self->_get({
         endpoint => '%s/link',
         ids      => [ $file_id ],
-    }); 
+    });
 }
 
 sub get_metadata {
@@ -60,11 +62,20 @@ sub get_metadata {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::File
+WebService::Mattermost::V4::API::Resource::File - Wrapped API methods for the file API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -127,5 +138,14 @@ Get information about a file.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
