@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Files;
 
+# ABSTRACT: Wrapped API methods for the files API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -31,11 +33,20 @@ sub upload {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Files
+WebService::Mattermost::V4::API::Resource::Files - Wrapped API methods for the files API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -74,5 +85,14 @@ Upload a file to a channel.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
