@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::License;
 
+# ABSTRACT: Wrapped API methods for the license API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -39,11 +41,20 @@ sub client {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::License
+WebService::Mattermost::V4::API::Resource::License - Wrapped API methods for the license API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -86,5 +97,14 @@ L<Get client license|https://api.mattermost.com/#tag/system%2Fpaths%2F~1license~
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
