@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Logs;
 
+# ABSTRACT: Wrapped API methods for the logs API endpoints.
+
 use Moo;
 use Types::Standard 'Str';
 
@@ -31,11 +33,20 @@ sub add_message {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Logs
+WebService::Mattermost::V4::API::Resource::Logs - Wrapped API methods for the logs API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -76,5 +87,14 @@ L<Add log message|https://api.mattermost.com/#tag/system%2Fpaths%2F~1logs%2Fpost
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
