@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Plugins;
 
+# ABSTRACT: Wrapped API methods for the plugins API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -36,11 +38,20 @@ sub all_webapp {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Plugins
+WebService::Mattermost::V4::API::Resource::Plugins - Wrapped API methods for the plugins API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -83,5 +94,14 @@ L<Get webapp plugins|https://api.mattermost.com/#tag/plugins%2Fpaths%2F~1plugins
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
