@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Posts;
 
+# ABSTRACT: Wrapped API methods for the posts API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -62,11 +64,20 @@ sub _validate_minimum_post_args {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Posts
+WebService::Mattermost::V4::API::Resource::Posts - Wrapped API methods for the posts API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -129,5 +140,14 @@ Official "posts" API documentation.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
