@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Role::Single;
 
+# ABSTRACT: Marks a resource as an object with an identifier.
+
 use Moo::Role;
 use Types::Standard 'Str';
 
@@ -10,11 +12,20 @@ has id => (is => 'rw', isa => Str, required => 0);
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Role::Single
+WebService::Mattermost::V4::API::Resource::Role::Single - Marks a resource as an object with an identifier.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -36,5 +47,14 @@ String.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
