@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Role::View::ChannelMember;
 
+# ABSTRACT: Links a resource to the channel member view.
+
 use Moo::Role;
 use Types::Standard 'Str';
 
@@ -10,11 +12,20 @@ has view_name => (is => 'ro', isa => Str, default => 'ChannelMember');
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Role::View::ChannelMember
+WebService::Mattermost::V4::API::Resource::Role::View::ChannelMember - Links a resource to the channel member view.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -31,5 +42,14 @@ view.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
