@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Roles;
 
+# ABSTRACT: Wrapped API methods for the roles API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -62,11 +64,20 @@ sub get_by_names {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Roles
+WebService::Mattermost::V4::API::Resource::Roles - Wrapped API methods for the roles API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -120,5 +131,14 @@ L<Get a list of roles by name|https://api.mattermost.com/#tag/roles%2Fpaths%2F~1
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
