@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Team;
 
+# ABSTRACT: Wrapped API methods for the team API endpoints.
+
 use Moo;
 use Types::Standard 'InstanceOf';
 
@@ -361,11 +363,20 @@ sub _build_channels {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Team
+WebService::Mattermost::V4::API::Resource::Team - Wrapped API methods for the team API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -540,5 +551,14 @@ L<Search for team posts|https://api.mattermost.com/#tag/posts%2Fpaths%2F~1teams~
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
