@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Team::Channels;
 
+# ABSTRACT: Wrapped API methods for the team channels API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -124,11 +126,20 @@ sub by_name_and_team_name {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Team::Channels
+WebService::Mattermost::V4::API::Resource::Team::Channels - Wrapped API methods for the team channels API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -201,5 +212,14 @@ L<Search channels|https://api.mattermost.com/#tag/channels%2Fpaths%2F~1teams~1%7
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
