@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::User;
 
+# ABSTRACT: Wrapped API methods for the users API endpoints.
+
 use Moo;
 use Types::Standard qw(HashRef Str);
 
@@ -196,8 +198,7 @@ sub update_active_status {
     my $id   = shift;
     my $args = shift;
 
-    return $self->_call({
-        method     => $self->put,
+    return $self->_put({
         endpoint   => '%s/active',
         ids        => [ $id ],
         parameters => $args,
@@ -432,11 +433,20 @@ sub _build_available_user_roles {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::User
+WebService::Mattermost::V4::API::Resource::User - Wrapped API methods for the users API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -748,5 +758,14 @@ L<Get authorized OAuth apps|https://api.mattermost.com/#tag/OAuth%2Fpaths%2F~1us
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
