@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Users;
 
+# ABSTRACT: Wrapped API methods for the users API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -227,11 +229,20 @@ sub search_tokens {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Users
+WebService::Mattermost::V4::API::Resource::Users - Wrapped API methods for the users API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -406,5 +417,14 @@ Get a user by email address.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
