@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::WebRTC;
 
+# ABSTRACT: Wrapped API methods for the WebRTC API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -18,14 +20,27 @@ sub get_token {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::WebRTC
+WebService::Mattermost::V4::API::Resource::WebRTC - Wrapped API methods for the WebRTC API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
+B<This API endpoint was removed from Mattermost in version v5.6 (October 2018).
+As such, the methods in this class will not do anything when used with recent
+versions of Mattermost!>
+
 =head2 USAGE
 
     use WebService::Mattermost;
@@ -53,5 +68,14 @@ L<Get WebRTC token|https://api.mattermost.com/#tag/system%2Fpaths%2F~1webrtc~1to
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
