@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Resource::Webhook::Incoming;
 
+# ABSTRACT: Wrapped API methods for the incoming webhook API endpoints.
+
 use Moo;
 
 extends 'WebService::Mattermost::V4::API::Resource';
@@ -63,11 +65,20 @@ sub update_by_id {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Resource::Webhook::Incoming
+WebService::Mattermost::V4::API::Resource::Webhook::Incoming - Wrapped API methods for the incoming webhook API endpoints.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -139,5 +150,14 @@ L<Update an incoming webhook|https://api.mattermost.com/#tag/webhooks%2Fpaths%2F
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
