@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Response;
 
+# ABSTRACT: Container for API responses.
+
 use Mojo::JSON 'decode_json';
 use Moo;
 use Types::Standard qw(Any ArrayRef Bool InstanceOf Int Maybe Object Str);
@@ -7,6 +9,7 @@ use Types::Standard qw(Any ArrayRef Bool InstanceOf Int Maybe Object Str);
 use WebService::Mattermost::V4::API::Object::Analytics::Old;
 use WebService::Mattermost::V4::API::Object::Application;
 use WebService::Mattermost::V4::API::Object::Audit;
+use WebService::Mattermost::V4::API::Object::Bot;
 use WebService::Mattermost::V4::API::Object::Channel::Member;
 use WebService::Mattermost::V4::API::Object::Channel;
 use WebService::Mattermost::V4::API::Object::ChannelStats;
@@ -137,11 +140,20 @@ sub _build_items {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::API::Response - container for responses from the Mattermost API
+WebService::Mattermost::V4::API::Response - Container for API responses.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -200,5 +212,14 @@ All view objects.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
