@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::API::Role::RequireID;
 
+# ABSTRACT: ID validation.
+
 use Moo::Role;
 use Types::Standard 'RegexpRef';
 
@@ -27,17 +29,26 @@ sub validate_id_no_next {
     my $self = shift;
     my $id   = shift;
 
-    return $id =~ $self->id_validation_regexp ? 1 : 0;
+    return ($id && $id =~ $self->id_validation_regexp) ? 1 : 0;
 }
 
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::API::Role::RequireID
+WebService::Mattermost::V4::API::Role::RequireID - ID validation.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -70,5 +81,14 @@ Basic UUID matching regular expression.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
