@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::Client;
 
+# ABSTRACT: Perl websocket client for Mattermost.
+
 use Encode 'encode';
 use Mojo::IOLoop;
 use Mojo::JSON qw(decode_json encode_json);
@@ -295,11 +297,20 @@ sub _build_websocket_url {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::WS::v4 - WebSocket gateway to Mattermost
+WebService::Mattermost::V4::Client - Perl websocket client for Mattermost.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -368,5 +379,14 @@ Can be overridden as C<gw_message_no_event()>.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
