@@ -1,5 +1,7 @@
 package WebService::Mattermost::V4::Example::Bot;
 
+# ABSTRACT: An example Perl Mattermost bot.
+
 use Moo; # or Moose
 
 extends 'WebService::Mattermost::V4::Client';
@@ -70,11 +72,20 @@ sub gw_message_no_event {
 ################################################################################
 
 1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-WebService::Mattermost::V4::Example::Bot
+WebService::Mattermost::V4::Example::Bot - An example Perl Mattermost bot.
+
+=head1 VERSION
+
+version 0.23
 
 =head1 DESCRIPTION
 
@@ -129,5 +140,14 @@ Triggered when a message without an event is received from the gateway.
 
 =head1 AUTHOR
 
-Mike Jones L<email:mike@netsplit.org.uk>
+Mike Jones <mike@netsplit.org.uk>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Mike Jones.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
